@@ -22,6 +22,7 @@ import six
 from six.moves.urllib import request
 import yaml
 
+from heatclient._i18n import _
 from heatclient.common import deployment_utils
 from heatclient.common import event_utils
 from heatclient.common import hook_utils
@@ -30,16 +31,13 @@ from heatclient.common import template_format
 from heatclient.common import template_utils
 from heatclient.common import utils
 import heatclient.exc as exc
-from heatclient.openstack.common._i18n import _
-from heatclient.openstack.common._i18n import _LI
-from heatclient.openstack.common._i18n import _LW
 
 logger = logging.getLogger(__name__)
 
 
 def show_deprecated(deprecated, recommended):
-    logger.warning(_LW('"%(old)s" is deprecated, '
-                       'please use "%(new)s" instead'),
+    logger.warning('"%(old)s" is deprecated, '
+                   'please use "%(new)s" instead',
                    {'old': deprecated,
                     'new': recommended}
                    )
@@ -105,8 +103,8 @@ def do_stack_create(hc, args):
         env_paths=args.environment_file, env_list_tracker=env_files_list)
 
     if args.create_timeout:
-        logger.warning(_LW('%(arg1)s is deprecated, '
-                           'please use %(arg2)s instead'),
+        logger.warning('%(arg1)s is deprecated, '
+                       'please use %(arg2)s instead',
                        {
                            'arg1': '-c/--create-timeout',
                            'arg2': '-t/--timeout'})
@@ -192,8 +190,8 @@ def do_stack_adopt(hc, args):
         raise exc.CommandError('Invalid adopt-file, no data!')
 
     if args.create_timeout:
-        logger.warning(_LW('%(arg1)s is deprecated, '
-                           'please use %(arg2)s instead'),
+        logger.warning('%(arg1)s is deprecated, '
+                       'please use %(arg2)s instead',
                        {
                            'arg1': '-c/--create-timeout',
                            'arg2': '-t/--timeout'})
@@ -304,20 +302,20 @@ def do_stack_delete(hc, args):
 
     try:
         if not args.yes and sys.stdin.isatty():
-            sys.stdout.write(
-                _("Are you sure you want to delete this stack(s) [y/N]? "))
-            prompt_response = sys.stdin.readline().lower()
+            prompt_response = six.moves.input(
+                _("Are you sure you want to delete this stack(s) [y/N]? ")
+            ).lower()
             if not prompt_response.startswith('y'):
-                logger.info(_LI(
-                    'User did not confirm stack delete so taking no action.'))
+                logger.info(
+                    'User did not confirm stack delete so taking no action.')
                 return
     except KeyboardInterrupt:  # ctrl-c
-        logger.info(_LI(
-            'User did not confirm stack delete (ctrl-c) so taking no action.'))
+        logger.info(
+            'User did not confirm stack delete (ctrl-c) so taking no action.')
         return
     except EOFError:  # ctrl-d
-        logger.info(_LI(
-            'User did not confirm stack delete (ctrl-d) so taking no action.'))
+        logger.info(
+            'User did not confirm stack delete (ctrl-d) so taking no action.')
         return
 
     for sid in args.id:
@@ -417,7 +415,7 @@ def do_action_check(hc, args):
 @utils.arg('id', metavar='<NAME or ID>',
            help=_('Name or ID of stack to describe.'))
 @utils.arg('--no-resolve-outputs', action="store_true",
-           help='Do not resolve outputs of the stack.')
+           help=_('Do not resolve outputs of the stack.'))
 def do_stack_show(hc, args):
     '''Describe the stack.'''
     show_deprecated('heat stack-show', 'openstack stack show')
@@ -462,10 +460,10 @@ def do_stack_show(hc, args):
                   'updated.')
            % {'true': strutils.TRUE_STRINGS, 'false': strutils.FALSE_STRINGS})
 @utils.arg('-y', '--dry-run', default=False, action="store_true",
-           help='Do not actually perform the stack update, but show what '
-           'would be changed')
+           help=_('Do not actually perform the stack update, but show what '
+                  'would be changed'))
 @utils.arg('-n', '--show-nested', default=False, action="store_true",
-           help='Show nested stacks when performing --dry-run')
+           help=_('Show nested stacks when performing --dry-run'))
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help=_('Parameter values used to create the stack. '
                   'This can be specified multiple times, or once with '
@@ -604,17 +602,21 @@ def do_stack_cancel_update(hc, args):
                   'parameters separated by a semicolon.'),
            action='append')
 @utils.arg('-t', '--tags', metavar='<TAG1,TAG2...>',
-           help=_('Show stacks containing these tags, combine multiple tags '
-                  'using the boolean AND expression'))
+           help=_('Show stacks containing these tags. If multiple tags '
+                  'are passed, they will be combined using the AND '
+                  'boolean expression. '))
 @utils.arg('--tags-any', metavar='<TAG1,TAG2...>',
-           help=_('Show stacks containing these tags, combine multiple tags '
-                  'using the boolean OR expression'))
+           help=_('Show stacks containing these tags, If multiple tags '
+                  'are passed, they will be combined using the OR '
+                  'boolean expression. '))
 @utils.arg('--not-tags', metavar='<TAG1,TAG2...>',
-           help=_('Show stacks not containing these tags, combine multiple '
-                  'tags using the boolean AND expression'))
+           help=_('Show stacks not containing these tags, If multiple tags '
+                  'are passed, they will be combined using the AND '
+                  'boolean expression. '))
 @utils.arg('--not-tags-any', metavar='<TAG1,TAG2...>',
-           help=_('Show stacks not containing these tags, combine multiple '
-                  'tags using the boolean OR expression'))
+           help=_('Show stacks not containing these tags, If multiple tags '
+                  'are passed, they will be combined using the OR '
+                  'boolean expression. '))
 @utils.arg('-l', '--limit', metavar='<LIMIT>',
            help=_('Limit the number of stacks returned.'))
 @utils.arg('-m', '--marker', metavar='<ID>',
@@ -631,7 +633,8 @@ def do_stack_cancel_update(hc, args):
                   'keys.'))
 @utils.arg('-g', '--global-tenant', action='store_true', default=False,
            help=_('Display stacks from all tenants. Operation only authorized '
-                  'for users who match the policy in heat\'s policy.json.'))
+                  'for users who match the policy (default or explicitly '
+                  'configured in policy.json) in heat.'))
 @utils.arg('-o', '--show-owner', action='store_true', default=False,
            help=_('Display stack owner information. This is automatically '
                   'enabled when using %(arg)s.') % {'arg': '--global-tenant'})
@@ -685,13 +688,16 @@ def do_stack_list(hc, args=None):
 
         if args.global_tenant or args.show_owner:
             fields.append('stack_owner')
-        if args.global_tenant:
-            fields.append('project')
 
         if args.show_deleted:
             fields.append('deletion_time')
 
     stacks = hc.stacks.list(**kwargs)
+    stacks = list(stacks)
+    for stk in stacks:
+        if hasattr(stk, 'project'):
+            fields.append('project')
+            break
     utils.print_list(stacks, fields, sortby_index=sortby_index)
 
 
@@ -724,7 +730,7 @@ def do_output_list(hc, args):
            help=_('Name of an output to display.'))
 @utils.arg('-F', '--format', metavar='<FORMAT>',
            help=_('The output value format, one of: json, raw.'),
-           default='json')
+           default='raw')
 @utils.arg('-a', '--all', default=False, action='store_true',
            help=_('Display all stack outputs.'))
 @utils.arg('--with-detail', default=False, action="store_true",
@@ -767,11 +773,11 @@ def do_output_show(hc, args):
             }
             utils.print_dict(output['output'], formatters=formatters)
         else:
-            if (args.format == 'json'
-                    or isinstance(output['output']['output_value'], dict)
-                    or isinstance(output['output']['output_value'], list)):
-                print(
-                    utils.json_formatter(output['output']['output_value']))
+            if args.format == 'json':
+                print(utils.json_formatter(output['output']))
+            elif (isinstance(output['output']['output_value'], dict)
+                  or isinstance(output['output']['output_value'], list)):
+                print(utils.json_formatter(output['output']['output_value']))
             else:
                 print(output['output']['output_value'])
 
@@ -1077,7 +1083,7 @@ def do_resource_signal(hc, args):
 @utils.arg('id', metavar='<NAME or ID>',
            help=_('Name or ID of stack the resource belongs to.'))
 @utils.arg('resource', metavar='<RESOURCE>',
-           help=_('Name of the resource.'))
+           help=_('Name or physical ID of the resource.'))
 @utils.arg('reason', default="", nargs='?',
            help=_('Reason for state change.'))
 @utils.arg('--reset', default=False, action="store_true",
@@ -1629,13 +1635,34 @@ def do_snapshot_show(hc, args):
            help=_('Name or ID of the stack containing the snapshot.'))
 @utils.arg('snapshot', metavar='<SNAPSHOT>',
            help=_('The ID of the snapshot to delete.'))
+@utils.arg('-y', '--yes', default=False, action="store_true",
+           help=_('Skip yes/no prompt (assume yes).'))
 def do_snapshot_delete(hc, args):
     '''Delete a snapshot of a stack.'''
     show_deprecated('heat snapshot-delete', 'openstack stack snapshot delete')
-
+    msg = "User did not confirm snapshot delete %sso taking no action."
+    try:
+        if not args.yes and sys.stdin.isatty():
+            sys.stdout.write(
+                _('Are you sure you want to delete the snapshot of this '
+                  'stack [Y/N]?'))
+            prompt_response = sys.stdin.readline().lower()
+            if not prompt_response.startswith('y'):
+                logger.info(msg, '')
+                return
+    except KeyboardInterrupt:  # ctrl-c
+        logger.info(msg, '(ctrl-c) ')
+        return
+    except EOFError:  # ctrl-d
+        logger.info(msg, '(ctrl-d) ')
+        return
     fields = {'stack_id': args.id, 'snapshot_id': args.snapshot}
     try:
         hc.stacks.snapshot_delete(**fields)
+        success_msg = _("Request to delete the snapshot %(snapshot_id)s of "
+                        "the stack %(stack_id)s has been accepted.")
+        print(success_msg % {'stack_id': args.id,
+                             'snapshot_id': args.snapshot})
     except exc.HTTPNotFound:
         raise exc.CommandError(_('Stack or snapshot not found'))
 
